==> haskell-colour-2.3.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.3
id: colour-2.3.3-4GTcWhusU4z5FdC5GspM4b
key: colour-2.3.3-4GTcWhusU4z5FdC5GspM4b
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
author: Russell O'\''Connor
exposed: True
indefinite: False
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
abi: 1add4d1e6d6c747aa6aecaf0add5c8e8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/colour-2.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/colour-2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-colour
hs-libraries: HScolour-2.3.3-4GTcWhusU4z5FdC5GspM4b
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colour-2.3.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.3
id: colour-2.3.3-BQD1Vp5Ogu6Fvom5yNWhu8
key: colour-2.3.3-BQD1Vp5Ogu6Fvom5yNWhu8
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
author: Russell O'\''Connor
exposed: True
indefinite: False
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
abi: bacb9545da72fadb6a27d40ac7c82525
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/colour-2.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/colour-2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-colour
hs-libraries: HScolour-2.3.3-BQD1Vp5Ogu6Fvom5yNWhu8
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
